@@ -50,8 +50,8 @@ extern "C" {
 #endif
 
 /* Specify which architecture libffi is configured for. */
-#ifndef SPARC
-#define SPARC
+#ifndef X86_64
+#define X86_64
 #endif
 
 /* ---- System configuration information --------------------------------- */
